msm: subsystem-fatal-8x60: Increase post-NMI delay to 100ms
The Q6 processor requires approximately 100ms to
flush its caches and perform other housekeeping
in its NMI handler. Increase the delay after
setting the NMI bit to 100ms.
Signed-off-by: Vikram Mulukutla <markivx@codeaurora.org>
diff --git a/arch/arm/mach-msm/subsystem-fatal-8x60.c b/arch/arm/mach-msm/subsystem-fatal-8x60.c
index 8fed7a6..b830591 100644
--- a/arch/arm/mach-msm/subsystem-fatal-8x60.c
+++ b/arch/arm/mach-msm/subsystem-fatal-8x60.c
@@ -78,8 +78,8 @@
iounmap(q6_wakeup_intr);
mb();
- /* Q6 requires atleast 5ms to dump caches etc.*/
- usleep(5000);
+ /* Q6 requires atleast 100ms to dump caches etc.*/
+ msleep(100);
pr_info("subsystem-fatal-8x60: Q6 NMI was sent.\n");
}